@@ -2,7 +2,7 @@
 /*
  * gsf-msole-impl.h: 
  *
- * Copyright (C) 2002-2003 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2004 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2.1 of the GNU Lesser General Public
@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -34,7 +34,8 @@ G_BEGIN_DECLS
 #define OLE_HEADER_BYTE_ORDER	 0x1c	/* 0xfe 0xff == Intel Little Endian */
 #define OLE_HEADER_BB_SHIFT      0x1e
 #define OLE_HEADER_SB_SHIFT      0x20
-/* 0x22..0x2b reserved == 0 */
+/* 0x22..0x27 reserved == 0 */
+#define OLE_HEADER_CSECTDIR	 0x28
 #define OLE_HEADER_NUM_BAT	 0x2c
 #define OLE_HEADER_DIRENT_START  0x30
 /* 0x34..0x37 transacting signature must be 0 */
@@ -78,14 +79,6 @@ G_BEGIN_DECLS
 #define BAT_MAGIC_BAT		0xfffffffd	/* a bat block,    -3 */
 #define BAT_MAGIC_METABAT	0xfffffffc	/* a metabat block -4 */
 
-/* The most common values */
-#define OLE_DEFAULT_THRESHOLD	 0x1000
-#define OLE_DEFAULT_SB_SHIFT	 6
-#define OLE_DEFAULT_SB_SIZE	 (1 << OLE_DEFAULT_SB_SHIFT)
-#define OLE_DEFAULT_BB_SHIFT	 9
-#define OLE_DEFAULT_BB_SIZE	 (1 << OLE_DEFAULT_BB_SHIFT)
-#define OLE_DEFAULT_METABAT_SIZE ((1 << (OLE_DEFAULT_BB_SHIFT - 2)) - 1)
-
 G_END_DECLS
 
 #endif /* GSF_MSOLE_IMPL_H */
